@@ -60,7 +60,15 @@
 #'
 #' @param sig.level alpha level to use. If set to \code{NA} then the empirical
 #'   alpha will be estimated given the fixed \code{conditions} input
-#'   (e.g., for criterion power analysis)
+#'   (e.g., for criterion power analysis). Only used when the value returned
+#'   from the experiment is a \code{numeric} (p-value).
+#'
+#'   If the return of the supplied experiment is a
+#'   \code{logical}, which generally indicates that a confidence interval (CI)
+#'   approach were used,
+#'   then an argument such as \code{conf.level} should be included
+#'   in the simulation experiment to indicate the explicit CI
+#'   criteria, and so that this can be modified directly as well
 #'
 #' @param interval search interval to use when \code{\link[SimDesign]{SimSolve}} is required.
 #'   Note that for compromise analyses, where the \code{sig.level} is set to
@@ -125,7 +133,8 @@
 #' @author Phil Chalmers \email{rphilip.chalmers@@gmail.com}
 #'
 #' @seealso \code{\link{update}}, \code{\link{SpowerCurve}},
-#'   \code{\link{getLastSpower}}
+#'   \code{\link{getLastSpower}}, \code{\link{is.CI_within}},
+#'   \code{\link{is.outside_CI}}
 #'
 #' @export
 #'
@@ -293,6 +302,65 @@
 #' # prospective power, can be used to extract the adjacent information
 #' p_my_t.test(n = 100, d = .5) |> Spower() -> post
 #'
+#' ###############################
+#' # Using CIs instead of p-values
+#' ###############################
+#'
+#' # CI test returning TRUE if psi0 is outside the 95% CI
+#' ci_ind.t.test <- function(n, d, psi0=0, conf.level=.95){
+#'   g1 <- rnorm(n)
+#'   g2 <- rnorm(n, mean=d)
+#'   CI <- t.test(g2, g1, var.equal=TRUE,conf.level=conf.level)$conf.int
+#'   is.outside_CI(psi0, CI)
+#' }
+#'
+#' # returns logical
+#' ci_ind.t.test(n=100, d=.2)
+#' ci_ind.t.test(n=100, d=.2)
+#'
+#' # simulated prospective power
+#' ci_ind.t.test(n=100, d=.2) |> Spower()
+#'
+#' # compare to pwr package
+#' pwr::pwr.t.test(n=100, d=.2)
+#'
+#' ############################
+#' # Equivalence test power using CIs
+#' #
+#' # H0: population d is outside interval [LB, UB] (not tolerably equivalent)
+#' # H1: population d is within interval [LB, UB]  (tolerably equivalent)
+#'
+#' # CI test returning TRUE if CI is within tolerable equivalence range (tol)
+#' ci_equiv.t.test <- function(n, d, tol, conf.level=.95){
+#'   g1 <- rnorm(n)
+#'   g2 <- rnorm(n, mean=d)
+#'   CI <- t.test(g2, g1, var.equal=TRUE,conf.level=conf.level)$conf.int
+#'   is.CI_within(CI, tol)
+#' }
+#'
+#' # evaluate if CI is within tolerable interval (tol)
+#' ci_equiv.t.test(n=1000, d=.2, tol=c(.1, .3))
+#'
+#' # simulated prospective power
+#' ci_equiv.t.test(n=1000, d=.2, tol=c(.1, .3)) |> Spower()
+#'
+#' # higher power with larger N (more precision) or wider tol interval
+#' ci_equiv.t.test(n=2000, d=.2, tol=c(.1, .3)) |> Spower()
+#' ci_equiv.t.test(n=1000, d=.2, tol=c(.1, .5)) |> Spower()
+#'
+#' ####
+#' # superiority test (one-tailed)
+#' # H0: population d is less than LB    (not superior)
+#' # H1: population d is greater than LB (superior)
+#'
+#' # set upper bound to Inf as it's not relevant, and reduce conf.level
+#' #   to reflect one-tailed test
+#' ci_equiv.t.test(n=1000, d=.2, tol=c(.1, Inf), conf.level=.90) |>
+#'   Spower()
+#'
+#' # higher LB means greater requirement for defining superiority (less power)
+#' ci_equiv.t.test(n=1000, d=.2, tol=c(.15, Inf), conf.level=.90) |>
+#'   Spower()
 #'
 #' }
 Spower <- function(..., power = NA, sig.level=.05, interval,
@@ -425,10 +493,6 @@ sim_function_aug <- function(condition, dat, fixed_objects){
 	pick <- fixed_objects$pick
 	if(length(pick))
 		fixed_objects$expr[pick] <- condition[pick]
-	if(!is.null(fixed_objects$prior)){
-		prior <- prior()
-		fixed_objects$expr[names(prior)] <- prior
-	}
 	ret <- eval(fixed_objects$expr, envir = fixed_objects$parent_frame)
 	if(is.logical(ret)) ret <- as.integer(!ret)
 	ret
